@@ -49,6 +49,7 @@ class Item : public QWidget, public QDeclarativeParserStatus
     Q_PRIVATE_PROPERTY(Item::d_func(), QDeclarativeListProperty<QObject> actions READ actions)
     Q_PRIVATE_PROPERTY(Item::d_func(), bool visible READ qmlVisible WRITE setQmlVisible NOTIFY visibleChanged)
     Q_PRIVATE_PROPERTY(Item::d_func(), bool focus READ hasFocus WRITE setFocus NOTIFY focusChanged)
+    Q_PRIVATE_PROPERTY(Item::d_func(), Style* style READ style WRITE setStyle RESET resetStyle)
 
     Q_INTERFACES(QDeclarativeParserStatus)
 
@@ -92,6 +93,7 @@ protected:
     virtual void hideEvent(QHideEvent *event);
     virtual void focusInEvent(QFocusEvent *event);
     virtual void focusOutEvent(QFocusEvent *event);
+    virtual void paintEvent(QPaintEvent *);
 
     virtual void classBegin();
     virtual void componentComplete();
@@ -99,6 +101,8 @@ protected:
     QScopedPointer<ItemPrivate> d_ptr;
 
     Q_DECLARE_PRIVATE(Item)
+    
+    Q_PRIVATE_SLOT(d_func(), void _q_onStyleChanged())
 
 private:
     Q_DISABLE_COPY(Item)
