@@ -16,10 +16,12 @@
  */
 
 #include "keys_p.h"
+#include "keyevent_p.h"
 #include <QDeclarativeEngine>
 #include <QDeclarativeContext>
 #include <QDeclarativeInfo>
 #include <QWidget>
+#include <QApplication>
 #include <QX11Info>
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
@@ -62,44 +64,6 @@ static const QList<int> KEYS = QList<int>() << Qt::Key_Asterisk
                                             << Qt::Key_F7 // Volume Up
                                             << Qt::Key_Yes;
 
-KeyEvent::KeyEvent(QKeyEvent *event, QObject *parent) :
-    QObject(parent),
-    m_event(event)
-{
-}
-
-KeyEvent::~KeyEvent() {}
-
-bool KeyEvent::isAccepted() const {
-    return (m_event) && (m_event->isAccepted());
-}
-
-void KeyEvent::setAccepted(bool accept) {
-    if (m_event) {
-        m_event->setAccepted(accept);
-    }
-}
-
-bool KeyEvent::isAutoRepeat() const {
-    return (m_event) && (m_event->isAutoRepeat());
-}
-
-int KeyEvent::count() const {
-    return m_event ? m_event->count() : 0;
-}
-
-int KeyEvent::key() const {
-    return m_event ? m_event->key() : 0;
-}
-
-int KeyEvent::modifiers() const {
-    return m_event ? m_event->modifiers() : Qt::NoModifier;
-}
-
-QString KeyEvent::text() const {
-    return m_event ? m_event->text() : QString();
-}
-
 class KeysPrivate
 {
 
@@ -308,8 +272,7 @@ bool Keys::eventFilter(QObject *obj, QEvent *event) {
         switch (keyEvent->type()) {
         case 7: // QKeyEvent::KeyPress
         {
-            KeyEvent *ke = new KeyEvent(keyEvent);
-            QDeclarativeEngine::setObjectOwnership(ke, QDeclarativeEngine::JavaScriptOwnership);
+            KeyEvent ke(*keyEvent);
             const int key = keyEvent->key();
 
             if (d->connections.contains(key)) {
@@ -318,12 +281,12 @@ bool Keys::eventFilter(QObject *obj, QEvent *event) {
 
                 if (this->receivers("2" + signature) > 0) {
                     keyEvent->accept();
-                    signal.invoke(this, Q_ARG(KeyEvent*, ke));
+                    signal.invoke(this, Q_ARG(KeyEvent*, &ke));
                 }
             }
 
             if (this->receivers(SIGNAL(pressed(KeyEvent*)))) {
-                emit pressed(ke);
+                emit pressed(&ke);
             }
 
             if (keyEvent->isAccepted()) {
@@ -334,9 +297,8 @@ bool Keys::eventFilter(QObject *obj, QEvent *event) {
         }
         case 8: // QKeyEvent::KeyRelease
             if (this->receivers(SIGNAL(released(KeyEvent*)))) {
-                KeyEvent *ke = new KeyEvent(keyEvent);
-                QDeclarativeEngine::setObjectOwnership(ke, QDeclarativeEngine::JavaScriptOwnership);
-                emit released(ke);
+                KeyEvent ke(*keyEvent);
+                emit released(&ke);
             }
 
             break;
@@ -352,19 +314,15 @@ void Keys::timerEvent(QTimerEvent *event) {
     this->killTimer(event->timerId());
 
     if ((this->receivers(SIGNAL(volumeDownPressed(KeyEvent*))) > 0) || (this->receivers(SIGNAL(volumeUpPressed(KeyEvent*))) > 0)) {
-        if (QDeclarativeContext *context = qmlContext(this)) {
-            if (QObject *pageStack = qvariant_cast<QObject*>(context->contextProperty("pageStack"))) {
-                if (QWidget *currentPage = qvariant_cast<QWidget*>(pageStack->property("currentPage"))) {
-                    Q_D(Keys);
-                    d->volumeKeysEnabled = true;
-                    d->windowId = currentPage->winId();
-                    d->grabVolumeKeys(d->windowId, true);
-                    return;
-                }
-            }
+        if (QWidget *window = QApplication::activeWindow()) {
+            Q_D(Keys);
+            d->volumeKeysEnabled = true;
+            d->windowId = window->winId();
+            d->grabVolumeKeys(d->windowId, true);
+        }
+        else {
+            qmlInfo(this) << tr("Could not find window id to grab volume keys");
         }
-
-        qmlInfo(this) << tr("Could not find window id to grab volume keys");
     }
 }
 
