@@ -14,44 +14,33 @@
  * along with this program; if not, write to the Free Software Foundation,
  * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
  */
- 
+
 #ifndef LISTELEMENT_P_H
 #define LISTELEMENT_P_H
 
-#include <QObject>
+#include <QDeclarativePropertyMap>
+#include <QDeclarativeParserStatus>
 #include <qdeclarative.h>
-#include <private/qdeclarativecustomparser_p.h>
 
-class ListElement : public QObject
+class ListElement : public QDeclarativePropertyMap, public QDeclarativeParserStatus
 {
     Q_OBJECT
     
+    Q_INTERFACES(QDeclarativeParserStatus)
+    
 public:
     explicit ListElement(QObject *parent = 0);
     ~ListElement();
     
+protected:
+    virtual void classBegin();
+    virtual void componentComplete();
+    
 private:
-    friend class ListElementParser;
-    friend class ListModelPrivate;
-    
-    QByteArray data;
-    
     Q_DISABLE_COPY(ListElement)
 };
 
-class ListElementParser : public QDeclarativeCustomParser
-{
-public:
-    virtual QByteArray compile(const QList<QDeclarativeCustomParserProperty> &);
-    virtual void setCustomData(QObject *, const QByteArray &);
-    
-private:
-    bool compileProperty(const QDeclarativeCustomParserProperty &prop, QByteArray &data);
-    bool definesEmptyList(const QString &);
-    
-    QByteArray listElementTypeName;
-};
-    
 QML_DECLARE_TYPE(ListElement)
 
 #endif // LISTELEMENT_P_H
+
