@@ -112,10 +112,9 @@ public:
     void setMaximumFlickVelocity(qreal maximum);
 
 public slots:
-    void positionViewAtBeginning();
-    void positionViewAtEnd();
-    void positionViewAtIndex(const QModelIndex &index, ScrollHint mode);
-    void positionViewAtIndex(int index, ScrollHint mode);
+    void positionViewAtBeginning(bool immediate = true);
+    void positionViewAtEnd(bool immediate = true);
+    void positionViewAtIndex(const QModelIndex &index, ScrollHint mode, bool immediate = true);
 
 signals:
     void parentChanged();
