@@ -19,13 +19,15 @@
 #define MENU_P_P_H
 
 #include "menu_p.h"
+#include "style_p.h"
 
 class MenuPrivate
 {
 
 public:
     MenuPrivate(Menu *parent) :
-        q_ptr(parent)
+        q_ptr(parent),
+        qmlStyle(0)
     {
     }
 
@@ -37,10 +39,18 @@ public:
 
     bool hasFocus() const;
     void setFocus(bool focus);
+    
+    Style* style() const;
+    void setStyle(Style *style);
+    void resetStyle();
+    
+    void _q_onStyleChanged();
 
     void componentComplete();
 
     Menu *q_ptr;
+    
+    Style *qmlStyle;
 
     bool complete;
 
